#
# spec file for package libgexiv2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define tarname gexiv2
%define pythons python3

Name:           libgexiv2
Version:        0.14.3
Release:        1.3
Summary:        A GObject-based Exiv2 wrapper
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://wiki.gnome.org/Projects/gexiv2
Source0:        https://download.gnome.org/sources/gexiv2/0.14/%{tarname}-%{version}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection
BuildRequires:  libtool
BuildRequires:  meson >= 0.48
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  pkgconfig(exiv2) >= 0.26
BuildRequires:  pkgconfig(gio-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.38.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(vapigen)

%description
gexiv2 is a GObject-based wrapper around the Exiv2 library. It makes the
basic features of Exiv2 available to GNOME applications.

%package -n libgexiv2-2
Summary:        A GObject-based Exiv2 wrapper
Group:          System/Libraries

%description -n libgexiv2-2
gexiv2 is a GObject-based wrapper around the Exiv2 library. It makes the
basic features of Exiv2 available to GNOME applications.

%package -n typelib-1_0-GExiv2-0_10
Summary:        A GObject-based Exiv2 wrapper - Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GExiv2-0_10
gexiv2 is a GObject-based wrapper around the Exiv2 library. It makes the
basic features of Exiv2 available to GNOME applications.

This package provides the GObject Introspection bindings for the
libgexiv2 library.

%package devel
Summary:        A GObject-based Exiv2 wrapper -- Development Files
Group:          Development/Libraries/C and C++
Requires:       libgexiv2-2 = %{version}

%description devel
gexiv2 is a GObject-based wrapper around the Exiv2 library. It makes the
basic features of Exiv2 available to GNOME applications.

%package -n python3-gexiv2
Summary:        A GObject-based Exiv2 wrapper
Group:          Development/Libraries/Python
Requires:       python3-gobject
BuildArch:      noarch

%description -n python3-gexiv2
gexiv2 is a GObject-based wrapper around the Exiv2 library. It makes the
basic features of Exiv2 available to GNOME applications.

This package provides the Python 3 bindings for the libgexiv2 library.

%prep
%autosetup -n %{tarname}-%{version} -p1

%build
%meson \
	-Dintrospection=true \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libgexiv2-2

%files -n libgexiv2-2
%license COPYING
%doc AUTHORS NEWS README.md THANKS
%{_libdir}/libgexiv2.so.*

%files -n typelib-1_0-GExiv2-0_10
%{_libdir}/girepository-1.0/GExiv2-0.10.typelib

%files devel
%{_datadir}/gir-1.0/GExiv2-0.10.gir
%{_includedir}/gexiv2/
%{_libdir}/libgexiv2.so
%{_libdir}/pkgconfig/gexiv2.pc
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gexiv2.vapi
%{_datadir}/vala/vapi/gexiv2.deps

%files -n python3-gexiv2
%{python3_sitelib}/*

%changelog
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.14.3:
  + Prevent std::exception escaping from exiv2
  + Declare gexiv2_metadata_open_stream and _save_stream as
    deprecated
  + Documentation updates
  + Bugs fixed: https://gitlab.gnome.org/GNOME/gexiv2/issues/81
* Wed Oct 11 2023 Bjørn <bjorn.lie@gmail.com>
- Package sub-package python3-gexiv2 as noarch.
* Wed Jul 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.14.2:
  + Make compatible with exiv2 0.28 or later.
  + Fix double free if creation of meta-data fails.
  + Fix floating point compare in tests.
- Drop patches fixed upstream:
  + 06adc8fb70cb8c77c0cd364195d8251811106ef8.patch
  + fix-32bit-compat.patch
* Fri Jun 30 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the biarch module is not used anymore.
* Wed Jun 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-32bit-compat.patch: Fix 32bit build compatibility. Taken
  from https://gitlab.gnome.org/GNOME/gexiv2/-/merge_requests/75
* Fri Jun 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 06adc8fb70cb8c77c0cd364195d8251811106ef8.patch: Fix
  compatibility with exiv2 main branch.
* Sun May  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.14.1:
  + Clean-up python support
  + Drop python2 support
  + Add option for building tests
  + Only run python tests when python is enabled
  + Fix get_gps_info() return data with unset altitude
  + Fix generate_xmp_packet() ignoring its parameters
  + Fix gexiv2-tool to call initialize()
- Use ldconfig_scriptlets macro.
* Wed Dec  1 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Set pythons python3 define, only build for python 3, following
  this, drop conditional sub-package python-gexiv2 and
  bcond_without macros. Use plain py3-*devel BuildRequires instead
  of python modules.
* Mon Sep 20 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.14.0:
  + Fix BMFF compile test.
- Changes from version 0.13.0:
  + Update gexiv2-dump tool
  + More additions to API and _try versions that support GErorr if
    exiv2 might throw
  + Some additions to gexiv2-tool
  + Changes in build configuration
* Tue Aug 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12.3:
  + Enable Exiv2's BMFF support if available
  + Catch WError on windows
  + Deprecate gexiv2_metadata_from_stream
  + Bugs fixed: glgo#GNOME/gexiv2#66
* Sat Feb 20 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12.2:
  + Introduce gexiv2_metadata_get_exif_data
  + Clarify License of C/C++ code
  + Documentation clean-up
  + Fix filename handling for windows
  + Fix _get_iptc_tags returning duplicates
  + Add _get_multiple() for all tag domains
  + Introduce a set of new functions that will pass on Exiv2's
    exception instead of silently dropping a warning to the console
  + Fix XMP tags sort order
  + Fix xmpText/altLang handling for _get_tag_multiple()
  + Add XMP namespace lookup
  + Windows compatibility fixes
* Sat May 23 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12.1:
  + Support macOS dylib versioning
  + Improve compatibility with current exiv2 development versions
  + Fix compiling on windows
  + Fix issue with problematic symbol visibility of exiv2
  + Fix issues with tests overwriting environment variables
  + Fix exception escaping on division by zero
  + Fix overflow in altitude fraction conversion
  + Fix crash with experimental GIO support
  + Documentation fixes
  + Add gexiv2_metadata_update_gps_info which will not remove all
    other GPS information
  + Bugs fixed: glgo#GNOME/gexiv2!41, glgo#GNOME/gexiv2!42,
    glgo#GNOME/gexiv2!45, glgo#GNOME/gexiv2!52,
    glgo#GNOME/gexiv2!53, glgo#GNOME/gexiv2!54,
    glgo#GNOME/gexiv2!55.
* Mon Mar 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to version 0.12.0:
  + Include a test for glgo#GNOME/shotwell!94.
  + Disable autoptr test when not running on GCC/Clang.
  + Revert symbol hiding script.
  + Improve building the vapi using meson's vala support.
  + Add canary test for glgo#GNOME/gexiv2!27.
  + Promote gexiv2-dump to a tool.
  + Documentation fixes.
  + flake8 fixes for python code.
  + Bugs fixed: glgo#GNOME/gexiv2!27.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 0.11.0:
  + Remove autotools.
  + Align Meson options with the rest of GNOME.
  + Prevent additional newlines from Exiv2 logging.
  + Remove VAPI overrides.
  + Adapt to Exiv2 changes in 0.27 and master.
  + Fix several issues with Gtk-Doc.
  + Add support to read Exiv2 meta-data from a GInputStream.
- Add explicit pkgconfig(gio-2.0) BuildRequires: meson checks for
  it.
- Pass -Dintrospection=true to meson, ensure we build introspection
  support.
* Tue Jan  1 2019 bjorn.lie@gmail.com
- Update to version 0.10.10:
  + Fix building against exiv2 0.27.
  + Various meson build fixes back-ported from master.
- Drop upstream fixed patches:
  + 0001-Handle-rename-of-exiv2-xmp.hpp-to-xmp_exiv2.hpp-in-e.patch
  + libgexiv2-build-Add-manifest-test-build-against-exiv2.patch
* Fri Dec 28 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix building with exiv2 0.27.0
  Add 0001-Handle-rename-of-exiv2-xmp.hpp-to-xmp_exiv2.hpp-in-e.patch
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Add libgexiv2-build-Add-manifest-test-build-against-exiv2.patch:
  Apply upstream fixes for new exiv2.
* Sun Nov 18 2018 bjorn.lie@gmail.com
- Update to version 0.10.9:
  + Fix check for building on OS X.
  + Fix generating non-reproducible builds.
  + Make it possible to disable the python modules.
  + Fix deprecated g_type_class_add_private.
  + Fix various issues with getting width and height from EXIF.
  + Fix building with 0.27.
- Drop libgexiv2-reproducible.patch: Fixed upstream.
- Switch to meson buildsystem following upstreams port, add meson
  BuildRequires and macros.
* Tue May  8 2018 bjorn.lie@gmail.com
- Add baselibs.conf, build 32-bit support.
* Tue Apr 10 2018 bjorn.lie@gmail.com
- Add libgexiv2-reproducible.patch: Avoid non-reproducible absolute
  build path in .h (bgo#793984).
* Tue Feb  6 2018 bjorn.lie@gmail.com
- Update to version 0.10.8:
  + Do not use linker scripts on Drawin/OS X.
  + Fallback to AperturValue if FNumber is absent.
  + Fix GIR header and vapi when using meson.
  + Bugs fixed: bgo#791941, bgo#792239, bgo#792431.
* Sat Feb  3 2018 bjorn.lie@gmail.com
- Update to version 0.10.7:
  + Add meson build support.
  + Use glib-mkenums for enum types.
  + Fix make check when running out of tree.
  + Use version script to clean up exported functions.
  + Fix --disable-vala.
  + Bugs fixed: bgo#784045, bgo#787455.
* Tue Jan 23 2018 tchvatal@suse.com
- Allow to enable/disable building of python2/python3 bindings via
  build conditions to accomodate potential python2-less products:
  + BuildRequire python-rpm-macros: helper macros from the
    python-singlespec initiative. Even though the package can't be
    built completley with singlespec due to the additional
    libraries, we can still make good use of the helpers.
  + Replace python-devel and python3-devel BuildRequires with
    python_module devel.
  + Replace python-gobject and python3-gobject BuildRequires with
    python_module gobjecta.
- Run test suite in %%check section.
- Correct URL to point to https://wiki.gnome.org/Projects/gexiv2.
* Thu Jul  6 2017 wbauer@tmo.at
- Update to version 0.10.6:
  + Fix missing include file.
  + Add a function to save meta-data in XMP sidecar file.
  + Add a more complete Python test-suite.
  + Fix a potential NULL dereference in _get_comment().
  + Fix compatibility with Exiv2 0.26.
  + Bugs fixed: Coverity issue CID 167853 (gentoo#613778,
    bgo#712455, bgo#780709, bgo#782449).
- Changes from version 0.10.5:
  + Fix autogen.sh to also run configure.
  + Generate gtk-doc and various documentation updates.
  + Fix an abort on unhandled Minolta meta-data.
  + Fix compilation issues with shadowing variables in StreamIO.
  + Fix GPS rational calculations if fraction has 0 numerator and
    denominator.
  + Several build cleanups.
  + Add make check to build and run the python tests.
  + Add C tests.
  + Bugs fixed: bgo#723790, bgo#774105, bgo#775249, bgo#776233,
    bgo#779089, bgo#779551, rh#1401706.
- Drop libgexiv2-fix-typelib-vapi-install.patch and
  get_orientation-Fix-abort-on-Minolta-meta-data.patch, fixed
  upstream.
- Add devel documentation to the file list.
* Thu Jan 19 2017 kkaempf@suse.com
- Add get_orientation-Fix-abort-on-Minolta-meta-data.patch: Fix
  abort on Minolta meta-data (bgo#776233).
* Sun Aug 21 2016 jengelh@inai.de
- Use %%_smp_mflags for parallel building; re-set RPM groups.
* Thu Aug 18 2016 zaitor@opensuse.org
- Add libgexiv2-fix-typelib-vapi-install.patch: Fix install
  location dir of typelib and always install vapi file. Taken from
  upstream git.
- Following the the above patch, pass autoreconf as it touches the
  buildsystem.
- Update Url to new home.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 0.10.4:
  + Additions to get_comment based on MWG guidelines (bgo#746424).
  + Fix builddir != srcdir.
  + Fix leaks in GPS coordinate handling (bgo#754241).
  + Update build instructions (bgo#749800).
  + Copyright transfer to SFC.
  + Use M4 macros for GObject introspection (bgo#765827).
  + Clean-up some introspection warnings.
  + Catch exception by reference (CID:112500).
  + Generate the VAPI file from GIR.
  + Mark _free() functions as deprecated.
  + Fix several g-i-scanner warnings.
  + Fix build issue introduced by VAPI changes (bgo#768896).
  + Use AX_COMPILER_FLAGS and fix issues risen by that.
  + Remove linker flags from CXXFLAGS.
  + Enable maintainer mode and silent rules.
  + Fix lookup of XMP tags (bgo#768906).
  + Enable compiling without GObject Introspection.
  + Bugs fixed: bgo#746424, bgo#749800, bgo#754241, bgo#765827,
    bgo#768896, bgo#768906.
- Add pkgconfig(vapigen) BuildRequires: New depenency.
* Mon Apr 18 2016 dimstar@opensuse.org
- Add gobject-introspection BuildRequires: needed in order to scan
  the python bindings for gi dependencies.
* Mon Jan  4 2016 rolf@rotkraut.de
- Build Python bindings:
  + Add python-devel, python3-devel, python-gobject and
    python3-gobject BuildRequires.
  + Split new packages python-gexiv2 and python3-gexiv2.
* Tue Mar 24 2015 zaitor@opensuse.org
- Update to version 0.10.3:
  + Retrieve XMP tag's structure type (bgo#736799).
  + Generate XMP packet as NUL-terminated string (bgo#736587).
  + Retrieve tag's raw value as GBytes (bgo#730136).
  + Fix gexiv2_metadata_get_fnumber() (bgo#745347).
* Sat Feb  7 2015 p.drouand@gmail.com
- Update to version 0.10.2:
  + Use all EXIF tags for interpreted strings (bgo#734861).
  + Automake fixes.
- Update download Url and use tarball provided by Gnome
- Rename typelib-1_0-GExiv2-0_4 to typelib-1_0-GExiv2-0_10; follow
  upstream changes.
- Use %%configure instead of manually defined options.
- Remove redundant %%clean section.
* Sun Oct 20 2013 zaitor@opensuse.org
- Update to version 0.7.0:
  + Fixed Python date/time getter/setter bindings.
  + Fixed latitude translation code.
  + New calls for getting underlying Exiv2 tag types.
* Sun Mar 24 2013 dimstar@opensuse.org
- Update to version 0.6.1:
  + Increases the libtool so version to 2.0.0 to reflect ABI
    changes introduced in 0.6.0.
- Rename libgexiv2-1 subpackage to libgexiv2-2, following upstreams
  soname bump.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 0.6.0:
  + API has been cleaned up: several unnecessary or questionable
    calls removed.
  + Improved support for developing GExiv2-based applications in
    Python.
  + Now includes calls to register and unregister custom XMP
    namespaces.
* Sun Oct 14 2012 zaitor@opensuse.org
- Update to version 0.5.0:
  + Corrects a major issue where some required directories wouldn't
    be created when running 'make install'.
  + Corrects an issue where gexiv2.py wouldn't get copied to the
    tarball when running 'make dist'.
  + Adds support for GObject introspection.
- Changes from version 0.4.90:
  + Corrected an issue with the makefile that would cause the GIR
    scanner to generate a lot of
    inconsequential-but-seemingly-ominous warnings.
  + Corrected handling of altitude in
    gexiv2_metadata_set_gps_info().
- Add pkgconfig(gobject-introspection-1.0), due to new upstream
  introspection support.
- Pass --enable-introspection to configure, to build introspection
  support.
- New subpackage typelib-1_0-GExiv2-0_4, containing introspection
  typelib.
- Switch to xz tarball, upstream does not provide tar.bz2 anymore.
- Drop conditional for obsolete openSUSE versions, we don't build
  for them anymore anyway.
* Thu Mar 29 2012 vuntz@opensuse.org
- Update to version 0.4.1:
  + Always build with -fPIC.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 0.4.0:
  + It's now possible (and advisable for multithreaded client
    applications) to initialize the XMP-handling subsystem in a
    thread-safe manner prior to encoding or decoding.
- Rename libgexiv2-0 subpackage to libgexiv2-1, following upstream
  soversion bump.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 0.3.92:
  + Exposes functionality to initialize the non-threadsafe parts
    of the XMP parser manually.
* Tue Feb 14 2012 vuntz@opensuse.org
- Update to version 0.3.91:
  + Add missing gexiv2-log-private.h.
- Remove gexiv2-log-private.h source file, and %%prep hackery now
  that the header is in the tarball.
* Sat Feb 11 2012 dimstar@opensuse.org
- Update to version 0.3.90:
  + Vala 0.15.1 support.
- Inject gexiv2-log-private.h as source file, as it's gone missing
  from the tarball
- Add check in %%prep section to not inject the source header once
  it is part of the tarball again.
* Sun Nov 13 2011 coolo@suse.com
- Add libtool as explicit BuildRequires to avoid implicit
  dependency from prjconf.
* Thu Apr 28 2011 dimstar@opensuse.org
- Update to version 0.3.1:
  + All debug and log messages from Exiv2 are now routed through
    GLib's logging functions.
- Changes from version 0.3.0:
  + Updated to work with Exiv2 0.21, which has an ABI/API change
    from 0.20.
* Fri Jan  7 2011 vuntz@opensuse.org
- Update to version 0.2.2:
  + A more general case fix from 0.2.1, where guards against empty
    nodes are now in place throughout the library.
* Sat Sep 11 2010 vuntz@opensuse.org
- Update to version 0.2.1:
  + Fixes a crash when an opened file has more than one
    Exif.Image.Orientation and the first one is empty.
* Thu Aug 26 2010 vuntz@opensuse.org
- Update to version 0.2.0:
  + Fixed a memory leak.
  + Other general bug fixes.
* Wed Aug 11 2010 vuntz@opensuse.org
- Initial package (version 0.1).
